@@ -243,13 +243,16 @@ class cmake_old(make):
         if cache_entries is None:
             cache_entries = []
         elif hasattr(cache_entries, 'items'):
-            cache_entries = cache_entries.items()
+            cache_entries = list(cache_entries.items())
 
         # add the RULE_LAUNCH settings for the build
         launcher_cmd = 'lbn-wrapcmd <CMAKE_CURRENT_BINARY_DIR> <TARGET_NAME>'
         cache_entries = (
             [('GAUDI_RULE_LAUNCH_%s' % n, launcher_cmd)
              for n in ('COMPILE', 'LINK', 'CUSTOM')] + cache_entries)
+        cache_entries.extend(
+            ('%s_INSTALL_VERSION' % p.name, p.version)
+            for p in (proj.slot.projects if proj.slot else []))
 
         cache_file = self._cache_preload_file(proj)
         ensure_dir(os.path.dirname(cache_file))
