@@ -220,7 +220,8 @@ class GitRepository(object):
             proc = Popen(['git', 'config', '--get-all', 'remote.origin.fetch'],
                          cwd=self.path,
                          stdout=PIPE)
-            if 'origin/merge-requests' not in proc.communicate()[0].decode():
+            if 'origin/merge-requests' not in proc.communicate()[0].decode(
+                    'utf-8', errors='replace'):
                 # it must be configured
                 __log__.getChild('git').debug(
                     'getting merge-requests branches')
@@ -240,7 +241,8 @@ class GitRepository(object):
         name -> url.
         '''
         proc = Popen(['git', 'remote', '-v'], cwd=self.path, stdout=PIPE)
-        lines = proc.communicate()[0].decode().splitlines()
+        lines = proc.communicate()[0].decode(
+            'utf-8', errors='replace').splitlines()
         pattern = re.compile(r'(\S+)\s+(\S+)\s+\(fetch\)$')
         return dict(
             m.groups() for m in filter(None, map(pattern.match, lines)))
@@ -252,15 +254,16 @@ class GitRepository(object):
         '''
         proc = Popen(['git', 'branch', '-a'], cwd=self.path, stdout=PIPE)
         return set(branch[2:].rstrip()
-                   for branch in proc.communicate()[0].decode().splitlines())
+                   for branch in proc.communicate()[0].decode(
+                       'utf-8', errors='replace').splitlines())
 
     def tags(self):
         '''
         Return a list of all tags known by the repository.
         '''
         proc = Popen(['git', 'tag'], cwd=self.path, stdout=PIPE)
-        return set(
-            tag.strip() for tag in proc.communicate()[0].decode().splitlines())
+        return set(tag.strip() for tag in proc.communicate()[0].decode(
+            'utf-8', errors='replace').splitlines())
 
     def add_remote(self, name, url, retry=True):
         '''
@@ -337,10 +340,11 @@ class GitRepository(object):
                 __log__.warning(str(err))
             return [
                 os.path.join(self.path,
-                             l.split()[1]) for l in
-                Popen(['git', 'submodule', 'status', '--recursive'],
-                      cwd=self.path,
-                      stdout=PIPE).communicate()[0].decode().splitlines()
+                             l.split()[1])
+                for l in Popen(['git', 'submodule', 'status', '--recursive'],
+                               cwd=self.path,
+                               stdout=PIPE).communicate()[0].decode(
+                                   'utf-8', errors='replace').splitlines()
             ]
         return []
 
@@ -407,7 +411,8 @@ class GitRepository(object):
         cmd = ['git', 'rev-parse']
         cmd.extend(args)
         return Popen(
-            cmd, cwd=self.path, stdout=PIPE).communicate()[0].decode().strip()
+            cmd, cwd=self.path, stdout=PIPE).communicate()[0].decode(
+                'utf-8', errors='replace').strip()
 
     def show_branch(self, *args):
         '''
@@ -529,7 +534,8 @@ class GitLabMergeRequestHandler(GitRepository):
         proc = Popen(['git', 'config', '--get-all', 'remote.origin.fetch'],
                      cwd=self.path,
                      stdout=PIPE)
-        if 'origin/merge-requests' not in proc.communicate()[0].decode():
+        if 'origin/merge-requests' not in proc.communicate()[0].decode(
+                'utf-8', errors='replace'):
             # it must be configured
             __log__.getChild('git').debug('getting merge-requests branches')
             fetch = ('+refs/merge-requests/*/head:'
@@ -820,12 +826,14 @@ def git(proj, url=None, commit=None, export=False, merges=None):
                 # (test requested commit first)
                 log.debug('looking for an equivalent commit')
                 for ref in eval('[{!r},'.format(commit_requested) +
-                                proc.communicate()[0].decode() + ']'):
+                                proc.communicate()[0].decode(
+                                    'utf-8', errors='replace') + ']'):
                     if repo.rev_parse(ref + ':') == tree:
                         proc = Popen(['git', 'rev-list', '--max-count=1', ref],
                                      cwd=repo.path,
                                      stdout=PIPE)
-                        commit = proc.communicate()[0].decode().strip()
+                        commit = proc.communicate()[0].decode(
+                            'utf-8', errors='replace').strip()
                         log.debug('reusing commit %s (%s)', commit, ref)
                         break  # we found a commit with the same content
                 else:  # we could not find it, so we stick to HEAD
